@@ -1,9 +1,17 @@
 test_that("test.is_null.na.returns_false", {
-  expect_false(assertive.properties::is_null(NA))
+  expect_false(actual <- assertive.properties::is_null(NA))
+  expect_match(
+    assertive.base::cause(actual),
+    "NA is not NULL; its value is NA"
+  )
 })
 
 test_that("test.is_null.nan.returns_false", {
-  expect_false(assertive.properties::is_null(NaN))
+  expect_false(actual <- assertive.properties::is_null(NaN))
+  expect_match(
+    assertive.base::cause(actual),
+    "NaN is not NULL; its value is NaN"
+  )
 })
 
 test_that("test.is_null.null.returns_true", {
@@ -19,5 +27,9 @@ test_that("test.is_not_null.nan.returns_true", {
 })
 
 test_that("test.is_not_null.null.returns_false", {
-  expect_false(assertive.properties::is_not_null(NULL))
+  expect_false(actual <- assertive.properties::is_not_null(NULL))
+  expect_match(
+    assertive.base::cause(actual),
+    "NULL is NULL"
+  )
 }) 
